package com.xylink.sdk;

import com.xylink.config.SDKConfig;
import com.xylink.config.SDKConfigMgr;
import com.xylink.util.SignatureSample;

import java.util.Map;
import java.util.TreeMap;

import static com.xylink.config.SignatureVersion.Signature_2_0_1;

/**
 * @Classname SdkMethodBase
 * @Date 2023/11/23 14:02
 * @Created by anan
 * @Description description here
 */
public class SdkMethodBase {
    private static final SignatureSample SIGNATURE_SAMPLE = new SignatureSample();

    /**
     * 添加签名
     *
     * @param url    url
     * @param token  token
     * @param body   body
     * @param method 请求方法
     * @return 返回拼接后的url
     */
    protected static String appendSignAndHost(String url, String token, String body, String method) {
        return appendSignAndHost(url, token, body, method, null);
    }
    protected static String appendSignAndHost(String url, String token, String body, String method, String clientId) {
        url = SIGNATURE_SAMPLE.appendSigniture(body, method, token, url, clientId);
        //2.0.1版本的签名需要规范化url

        SDKConfig sdkConfig = SDKConfigMgr.getSdkConfig(url, clientId);
        if (sdkConfig.getSignatureVersion().equals(Signature_2_0_1)){
            url = canonicalizedUri(url);
        }
        url = sdkConfig.getServerHost() + url;
        return url;
    }



    /**
     * 规范化uri
     * @param uri 原始请求uri (以/开始的完整请求地址, 包含参数部分)
     * @return 规范化后的uri
     * eg: /api?b=2&a=1&A=0
     * return: /api?A=0&a=1&b=2
     */
    private static String canonicalizedUri(String uri) {
        final int index = uri.indexOf("?");
        if (index > -1) {
            String uriPrefix = uri.substring(0, index);
            String uriSuffix = uri.substring(index + 1);
            StringBuilder canonicalizedUri = new StringBuilder(uriPrefix);
            StringBuilder canonicalizedQueryString = new StringBuilder();
            TreeMap<String, String> queryMap = new TreeMap<String, String>();

            if (uriSuffix.length() > 0) {
                final String[] pairs = uriSuffix.split("&");
                for (String pair : pairs) {
                    final int idx = pair.indexOf("=");
                    final String key = idx > 0 ? pair.substring(0, idx) : pair;
                    if (key.length() > 0 && !queryMap.containsKey(key)) {
                        final String value = idx > 0 ? pair.substring(idx + 1) : "";
                        queryMap.put(key, value);
                    }
                }
                for (Map.Entry<String, String> entry : queryMap.entrySet()) {
                    canonicalizedQueryString.append(entry.getKey()).append("=").append(entry.getValue()).append("&");
                }
                if (canonicalizedQueryString.length() > 1) {
                    canonicalizedQueryString.setLength(canonicalizedQueryString.length() - 1);
                }
            }
            if (canonicalizedQueryString.length() > 0) {
                canonicalizedUri.append("?").append(canonicalizedQueryString);
            }
            return canonicalizedUri.toString();
        }
        return uri;
    }
}
