package com.xylink.sdk.conferenceControl;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.*;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.util.Map;

public class CloudMeetingRoomApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrlMeetingInfo = "/api/rest/external/v1/conference/";



    /**
     * 根据类型查询企业的云会议室列表
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    public Result<Pager<ConferenceMeetingRoom>> getCloudMeetingRooms(String enterpriseId, String token, String type, int page, int size) throws IOException {
        String surl = getMeetingInfoPrefixUrl(enterpriseId) + "cloudConference?enterpriseId=" + enterpriseId + "&type=" + type + "&page=" + page + "&size=" + size;
        surl = signatureSample.appendSigniture("", "GET", token, surl);

        Result<String> resp = HttpUtil.getResponse(surl, "GET", null, String.class);

        Result<Pager<ConferenceMeetingRoom>> result = new Result<Pager<ConferenceMeetingRoom>>();
        result.setSuccess(resp.isSuccess());
        result.setErrorStatus(resp.getErrorStatus());
        result.setErrorMsg(resp.getErrorMsg());

        if (result.isSuccess() && StringUtils.isNotBlank(resp.getData())) {
            ObjectMapper objectMapper = new ObjectMapper();
            Pager<ConferenceMeetingRoom> pager = objectMapper.readValue(resp.getData(), new TypeReference<Pager<ConferenceMeetingRoom>>() {});
            result.setData(pager);
        }

        return result;
    }

    /**
     * 修改云会议室信息
     * @param enterpriseId
     * @param token
     * @param meetingRoomNumber
     * @param configs
     * @return
     * @throws IOException
     */
    public Result meetingRoomPropertyUpdate(String enterpriseId, String token, String meetingRoomNumber, Map configs) throws IOException {
        String surl = getMeetingInfoPrefixUrl(enterpriseId) + "meetingRoom/property/update?enterpriseId="+enterpriseId+"&meetingRoomNumber="+meetingRoomNumber;
        String jsonEntity = new ObjectMapper().writeValueAsString(configs);
        surl = signatureSample.appendSigniture(jsonEntity, "POST", token, surl);

        return HttpUtil.getResponse(surl, "POST", jsonEntity, Result.class);
    }


    private String getMeetingInfoPrefixUrl(String enterpriseId) {
        return SDKConfigMgr.getServerHost(enterpriseId) + prefixUrlMeetingInfo;
    }
}
