package com.xylink.sdk.enterpriseNemo;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.NemoDto;
import com.xylink.model.PageableNemoDto;
import com.xylink.model.UserDeviceDto;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

/**
 * created by maolizhi at 03/14/2017
 * get Enterprise Nemos
 */
public class EnterpriseNemoApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/buffet/nemos";
    private static final String externalPrefixUrl = "/api/rest/external/v1/";
    private static final ObjectMapper objectMapper = new ObjectMapper();

    /**
     * get enterprise all nemos(only nemo) acording to enterpriseId.
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<NemoDto[]> getEnterpriseNemos(String enterpriseId, String token) throws IOException{

        String surl = SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl + "?enterprise_id=" + enterpriseId;
        surl = signatureSample.appendSigniture("","GET",token,surl);

        return HttpUtil.getResponse(surl,"GET", null,NemoDto[].class);

    }

    public Result<NemoDto[]> addNemo2Enterprise(String enterpriseId, String token,List<UserDeviceDto> userDeviceDtos) throws IOException{
        String surl = SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl + "?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(userDeviceDtos);
        surl = signatureSample.appendSigniture(jsonEntity,"POST",token,surl);

        return HttpUtil.getResponse(surl,"POST", jsonEntity,String.class);
    }

    public Result<NemoDto[]> removeNemoFromEnterprise(String enterpriseId, String token,String nemoMumber) throws IOException{
        String surl = SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl + "?enterpriseId=" + enterpriseId+"&nemoNumber="+nemoMumber;
        String jsonEntity = "";
        surl = signatureSample.appendSigniture(jsonEntity,"DELETE",token,surl);

        return HttpUtil.getResponse(surl,"DELETE", jsonEntity,String.class);
    }

    /**
     * get enterprise pageable nemos(only nemo) acording to enterpriseId.
     * @param enterpriseId
     * @param token
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<PageableNemoDto> getPageableEnterpriseNemos(String enterpriseId, String token, int page, int pageSize) throws IOException{
        String surl = SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl + "/page?enterprise_id=" + enterpriseId + "&page=" + page + "&pageSize=" + pageSize;
        surl = signatureSample.appendSigniture("","GET",token,surl);

        return HttpUtil.getResponse(surl,"GET", null,PageableNemoDto.class);

    }

    /**
     * 分页查询企业下所有的设备列表
     * @param enterpriseId
     * @param token
     * @param pageIndex
     * @param pageSize
     * @return
     * @throws IOException
     */
    public Result getEnterpriseDevicesPage(String enterpriseId, String token,int pageIndex,int pageSize)throws IOException{
        String surl = SDKConfigMgr.getServerHost(enterpriseId) + externalPrefixUrl + "enterprise/device/page?enterpriseId="+enterpriseId+"&pageIndex="+pageIndex+"&pageSize="+pageSize;
        surl = signatureSample.appendSigniture("","GET",token,surl);

        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    /**
     * 修改设备名称
     * @param enterpriseId
     * @param token
     * @param nemoNumber
     * @param displayName
     * @return
     * @throws IOException
     */
    public Result editDeviceName(String enterpriseId, String token,String nemoNumber,String displayName)throws IOException{
        String surl = SDKConfigMgr.getServerHost(enterpriseId) + prefixUrl + "?enterpriseId="+enterpriseId+"&nemoNumber="+nemoNumber+"&displayName="+ URLEncoder.encode(displayName);
        surl = signatureSample.appendSigniture("","PUT",token,surl);

        return HttpUtil.getResponse(surl,"PUT", null, Map.class);
    }
}
